==> uimaj_2.10.2.orig.tar.xz: uimaj-2.10.2/uimaj-ep-cas-editor/src/main/java/org/apache/uima/caseditor/editor/ICasEditorInputListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.editor;

import org.eclipse.ui.IEditorInput;

public interface ICasEditorInputListener {

  /**
   * This method is called if an {@link ICasDocument} is exchanged.
   * The arguments of this methods can be null under certain circumstances.
   * For example, if a document is opened where the type system cannot be found 
   * for, then the new document will be null.
   * 
   * @param oldDocument
   *          - the replaced, old document {@link ICasDocument}.
   * @param newDocument
   *          - the new, current document {@link ICasDocument}.
   */
  void casDocumentChanged(IEditorInput oldInput, ICasDocument oldDocument, IEditorInput newInput, ICasDocument newDocument);
  
}

==> uimaj_2.10.4.orig.tar.xz: uimaj-2.10.4/uimaj-ep-cas-editor/src/main/java/org/apache/uima/caseditor/editor/ICasEditorInputListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.editor;

import org.eclipse.ui.IEditorInput;


/**
 * The listener interface for receiving ICasEditorInput events.
 * The class that is interested in processing a ICasEditorInput
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addICasEditorInputListener</code> method. When
 * the ICasEditorInput event occurs, that object's appropriate
 * method is invoked.
 */
public interface ICasEditorInputListener {

  /**
   * This method is called if an {@link ICasDocument} is exchanged.
   * The arguments of this methods can be null under certain circumstances.
   * For example, if a document is opened where the type system cannot be found 
   * for, then the new document will be null.
   *
   * @param oldInput the old input
   * @param oldDocument          - the replaced, old document {@link ICasDocument}.
   * @param newInput the new input
   * @param newDocument          - the new, current document {@link ICasDocument}.
   */
  void casDocumentChanged(IEditorInput oldInput, ICasDocument oldDocument, IEditorInput newInput, ICasDocument newDocument);
  
}
